@@ -4,20 +4,12 @@
  *
  * Implementation of templatized load() function defined in load.hpp.
  *
- * This file is part of MLPACK 1.0.8.
+ * This file is part of mlpack 1.0.12.
  *
- * MLPACK is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * MLPACK is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * MLPACK.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #ifndef __MLPACK_CORE_DATA_LOAD_IMPL_HPP
 #define __MLPACK_CORE_DATA_LOAD_IMPL_HPP
@@ -43,6 +35,7 @@ bool Load(const std::string& filename,
   size_t ext = filename.rfind('.');
   if (ext == std::string::npos)
   {
+    Timer::Stop("loading_data");
     if (fatal)
       Log::Fatal << "Cannot determine type of file '" << filename << "'; "
           << "no extension is present." << std::endl;
@@ -50,7 +43,6 @@ bool Load(const std::string& filename,
       Log::Warn << "Cannot determine type of file '" << filename << "'; "
           << "no extension is present.  Load failed." << std::endl;
 
-    Timer::Stop("loading_data");
     return false;
   }
 
@@ -65,13 +57,13 @@ bool Load(const std::string& filename,
 
   if (!stream.is_open())
   {
+    Timer::Stop("loading_data");
     if (fatal)
       Log::Fatal << "Cannot open file '" << filename << "'. " << std::endl;
     else
       Log::Warn << "Cannot open file '" << filename << "'; load failed."
           << std::endl;
 
-    Timer::Stop("loading_data");
     return false;
   }
 
@@ -157,7 +149,24 @@ bool Load(const std::string& filename,
 #ifdef ARMA_USE_HDF5
     loadType = arma::hdf5_binary;
     stringType = "HDF5 data";
+  #if ARMA_VERSION_MAJOR == 4 && \
+      (ARMA_VERSION_MINOR >= 300 && ARMA_VERSION_MINOR <= 400)
+    Timer::Stop("loading_data");
+    if (fatal)
+      Log::Fatal << "Attempted to load '" << filename << "' as HDF5 data, but "
+          << "Armadillo 4.300.0 through Armadillo 4.400.1 are known to have "
+          << "bugs and one of these versions is in use.  Load failed."
+          << std::endl;
+    else
+      Log::Warn << "Attempted to load '" << filename << "' as HDF5 data, but "
+          << "Armadillo 4.300.0 through Armadillo 4.400.1 are known to have "
+          << "bugs and one of these versions is in use.  Load failed."
+          << std::endl;
+
+    return false;
+  #endif
 #else
+    Timer::Stop("loading_data");
     if (fatal)
       Log::Fatal << "Attempted to load '" << filename << "' as HDF5 data, but "
           << "Armadillo was compiled without HDF5 support.  Load failed."
@@ -167,7 +176,6 @@ bool Load(const std::string& filename,
           << "Armadillo was compiled without HDF5 support.  Load failed."
           << std::endl;
 
-    Timer::Stop("loading_data");
     return false;
 #endif
   }
@@ -181,6 +189,7 @@ bool Load(const std::string& filename,
   // Provide error if we don't know the type.
   if (unknownType)
   {
+    Timer::Stop("loading_data");
     if (fatal)
       Log::Fatal << "Unable to detect type of '" << filename << "'; "
           << "incorrect extension?" << std::endl;
@@ -188,7 +197,6 @@ bool Load(const std::string& filename,
       Log::Warn << "Unable to detect type of '" << filename << "'; load failed."
           << " Incorrect extension?" << std::endl;
 
-    Timer::Stop("loading_data");
     return false;
   }
 
@@ -205,10 +213,13 @@ bool Load(const std::string& filename,
   if (!success)
   {
     Log::Info << std::endl;
+    Timer::Stop("loading_data");
     if (fatal)
       Log::Fatal << "Loading from '" << filename << "' failed." << std::endl;
     else
       Log::Warn << "Loading from '" << filename << "' failed." << std::endl;
+
+    return false;
   }
   else
     Log::Info << "Size is " << (transpose ? matrix.n_cols : matrix.n_rows)
