@@ -4,20 +4,12 @@
  *
  * Definition of the Epanechnikov kernel.
  *
- * This file is part of MLPACK 1.0.8.
+ * This file is part of mlpack 1.0.12.
  *
- * MLPACK is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * MLPACK is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * MLPACK.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #ifndef __MLPACK_CORE_KERNELS_EPANECHNIKOV_KERNEL_HPP
 #define __MLPACK_CORE_KERNELS_EPANECHNIKOV_KERNEL_HPP
@@ -73,6 +65,7 @@ class EpanechnikovKernel
    * @param b Second vector.
    * @return the convolution integral value.
    */
+  
   template<typename VecType>
   double ConvolutionIntegral(const VecType& a, const VecType& b);
 
@@ -82,12 +75,16 @@ class EpanechnikovKernel
    * @param dimension Dimension to calculate the normalizer for.
    */
   double Normalizer(const size_t dimension);
+  
+  // Returns String of O bject
+  std::string ToString() const;
 
  private:
   //! Bandwidth of the kernel.
   double bandwidth;
   //! Cached value of the inverse bandwidth squared (to speed up computation).
   double inverseBandwidthSquared;
+
 };
 
 //! Kernel traits for the Epanechnikov kernel.
