@@ -6,20 +6,12 @@
  *
  * Implementation of the Gaussian kernel (GaussianKernel).
  *
- * This file is part of MLPACK 1.0.8.
+ * This file is part of mlpack 1.0.12.
  *
- * MLPACK is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * MLPACK is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * MLPACK.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #ifndef __MLPACK_CORE_KERNELS_GAUSSIAN_KERNEL_HPP
 #define __MLPACK_CORE_KERNELS_GAUSSIAN_KERNEL_HPP
@@ -54,7 +46,7 @@ class GaussianKernel
    *
    * @param bandwidth The bandwidth of the kernel (@f$\mu@f$).
    */
-  GaussianKernel(double bandwidth) :
+  GaussianKernel(const double bandwidth) :
       bandwidth(bandwidth),
       gamma(-0.5 * pow(bandwidth, -2.0))
   { }
@@ -84,7 +76,7 @@ class GaussianKernel
    * @return K(t) using the bandwidth (@f$\mu@f$) specified in the
    *     constructor.
    */
-  double Evaluate(double t) const
+  double Evaluate(const double t) const
   {
     // The precalculation of gamma saves us a little computation time.
     return exp(gamma * std::pow(t, 2.0));
@@ -96,7 +88,7 @@ class GaussianKernel
    * @param dimension
    * @return the normalization constant
    */
-  double Normalizer(size_t dimension)
+  double Normalizer(const size_t dimension)
   {
     return pow(sqrt(2.0 * M_PI) * bandwidth, (double) dimension);
   }
@@ -130,6 +122,15 @@ class GaussianKernel
   //! Get the precalculated constant.
   double Gamma() const { return gamma; }
 
+  //! Convert object to string.
+  std::string ToString() const
+  {
+    std::ostringstream convert;
+    convert << "GaussianKernel [" << this << "]" << std::endl;
+    convert << "  Bandwidth: " << bandwidth << std::endl;
+    return convert.str();
+  }
+
  private:
   //! Kernel bandwidth.
   double bandwidth;
