@@ -8,20 +8,12 @@
  * strings; then, the actual strings are given to the PSpectrumStringKernel at
  * construction time, and the kernel knows to map the indices to actual strings.
  *
- * This file is part of MLPACK 1.0.8.
+ * This file is part of mlpack 1.0.12.
  *
- * MLPACK is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * MLPACK is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * MLPACK.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #ifndef __MLPACK_CORE_KERNELS_PSPECTRUM_STRING_KERNEL_HPP
 #define __MLPACK_CORE_KERNELS_PSPECTRUM_STRING_KERNEL_HPP
@@ -110,6 +102,20 @@ class PSpectrumStringKernel
   //! Modify the value of p.
   size_t& P() { return p; }
 
+   /*
+   * Returns a string representation of this object.
+   */
+  std::string ToString() const{
+    std::ostringstream convert;
+    convert << "PSpectrumStringKernel [" << this << "]" << std::endl;
+    convert << "  p used: " << p << std::endl;
+    convert << "  Dataset:" << datasets.size() << std::endl;
+    std::ostringstream convertb;
+    for (size_t ind=0; ind < datasets.size(); ind++)
+      convertb << datasets[ind].size();
+    convert << mlpack::util::Indent(convertb.str(),2);
+    return convert.str();
+  }
  private:
   //! The datasets.
   const std::vector<std::vector<std::string> >& datasets;
