@@ -4,20 +4,12 @@
  *
  * Definition and implementation of the trivially simple triangular kernel.
  *
- * This file is part of MLPACK 1.0.8.
+ * This file is part of mlpack 1.0.12.
  *
- * MLPACK is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * MLPACK is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * MLPACK.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #ifndef __MLPACK_CORE_KERNELS_TRIANGULAR_KERNEL_HPP
 #define __MLPACK_CORE_KERNELS_TRIANGULAR_KERNEL_HPP
@@ -76,6 +68,15 @@ class TriangularKernel
   //! Modify the bandwidth of the kernel.
   double& Bandwidth() { return bandwidth; }
 
+  //! Return a string representation of the kernel.
+  std::string ToString() const
+  {
+    std::ostringstream convert;
+    convert << "TriangularKernel [" << this << "]" << std::endl;
+    convert << "  Bandwidth: " << bandwidth << std::endl;
+    return convert.str();
+  }
+
  private:
   //! The bandwidth of the kernel.
   double bandwidth;
