@@ -4,20 +4,12 @@
  *
  * Definition of CoverTree, which can be used in place of the BinarySpaceTree.
  *
- * This file is part of MLPACK 1.0.8.
+ * This file is part of mlpack 1.0.12.
  *
- * MLPACK is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * MLPACK is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * MLPACK.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #ifndef __MLPACK_CORE_TREE_COVER_TREE_COVER_TREE_HPP
 #define __MLPACK_CORE_TREE_COVER_TREE_COVER_TREE_HPP
@@ -335,6 +327,10 @@ class CoverTree
   //! descendant.
   double& FurthestDescendantDistance() { return furthestDescendantDistance; }
 
+  //! Get the minimum distance from the center to any bound edge (this is the
+  //! same as furthestDescendantDistance).
+  double MinimumBoundDistance() const { return furthestDescendantDistance; }
+
   //! Get the centroid of the node and store it in the given vector.
   void Centroid(arma::vec& centroid) const { centroid = dataset.col(point); }
 
