@@ -4,20 +4,12 @@
  *
  * A dual-tree traverser for the cover tree.
  *
- * This file is part of MLPACK 1.0.8.
+ * This file is part of mlpack 1.0.12.
  *
- * MLPACK is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * MLPACK is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * MLPACK.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #ifndef __MLPACK_CORE_TREE_COVER_TREE_DUAL_TREE_TRAVERSER_HPP
 #define __MLPACK_CORE_TREE_COVER_TREE_DUAL_TREE_TRAVERSER_HPP
@@ -28,10 +20,6 @@
 namespace mlpack {
 namespace tree {
 
-//! Forward declaration of struct to be used for traversal.
-template<typename MetricType, typename RootPointPolicy, typename StatisticType>
-struct DualCoverTreeMapEntry;
-
 template<typename MetricType, typename RootPointPolicy, typename StatisticType>
 template<typename RuleType>
 class CoverTree<MetricType, RootPointPolicy, StatisticType>::DualTreeTraverser
@@ -50,14 +38,6 @@ class CoverTree<MetricType, RootPointPolicy, StatisticType>::DualTreeTraverser
    */
   void Traverse(CoverTree& queryNode, CoverTree& referenceNode);
 
-  /**
-   * Helper function for traversal of the two trees.
-   */
-  void Traverse(CoverTree& queryNode,
-                std::map<int, std::vector<DualCoverTreeMapEntry<
-                    MetricType, RootPointPolicy, StatisticType> > >&
-                    referenceMap);
-
   //! Get the number of pruned nodes.
   size_t NumPrunes() const { return numPrunes; }
   //! Modify the number of pruned nodes.
@@ -76,17 +56,44 @@ class CoverTree<MetricType, RootPointPolicy, StatisticType>::DualTreeTraverser
   //! The number of pruned nodes.
   size_t numPrunes;
 
+  //! Struct used for traversal.
+  struct DualCoverTreeMapEntry
+  {
+    //! The node this entry refers to.
+    CoverTree<MetricType, RootPointPolicy, StatisticType>* referenceNode;
+    //! The score of the node.
+    double score;
+    //! The base case.
+    double baseCase;
+    //! The traversal info associated with the call to Score() for this entry.
+    typename RuleType::TraversalInfoType traversalInfo;
+
+    //! Comparison operator, for sorting within the map.
+    bool operator<(const DualCoverTreeMapEntry& other) const
+    {
+      if (score == other.score)
+        return (baseCase < other.baseCase);
+      else
+        return (score < other.score);
+    }
+  };
+
+  /**
+   * Helper function for traversal of the two trees.
+   */
+  void Traverse(CoverTree& queryNode,
+                std::map<int, std::vector<DualCoverTreeMapEntry> >&
+                    referenceMap);
+
   //! Prepare map for recursion.
   void PruneMap(CoverTree& queryNode,
-                std::map<int, std::vector<DualCoverTreeMapEntry<
-                    MetricType, RootPointPolicy, StatisticType> > >&
+                std::map<int, std::vector<DualCoverTreeMapEntry> >&
                     referenceMap,
-                std::map<int, std::vector<DualCoverTreeMapEntry<
-                    MetricType, RootPointPolicy, StatisticType> > >& childMap);
+                std::map<int, std::vector<DualCoverTreeMapEntry> >&
+                    childMap);
 
   void ReferenceRecursion(CoverTree& queryNode,
-                          std::map<int, std::vector<DualCoverTreeMapEntry<
-                              MetricType, RootPointPolicy, StatisticType> > >&
+                          std::map<int, std::vector<DualCoverTreeMapEntry> >&
                               referenceMap);
 };
 
