@@ -5,20 +5,12 @@
  * This file contains the specialization of the TreeTraits class for the
  * CoverTree type of tree.
  *
- * This file is part of MLPACK 1.0.8.
+ * This file is part of mlpack 1.0.12.
  *
- * MLPACK is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * MLPACK is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * MLPACK.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #ifndef __MLPACK_CORE_TREE_COVER_TREE_TRAITS_HPP
 #define __MLPACK_CORE_TREE_COVER_TREE_TRAITS_HPP
@@ -40,13 +32,6 @@ template<typename MetricType,
 class TreeTraits<CoverTree<MetricType, RootPointPolicy, StatisticType> >
 {
  public:
-  /**
-   * The cover tree calculates the distance between parent and child during
-   * construction, so that value is saved and CoverTree<...>::ParentDistance()
-   * does exist.
-   */
-  static const bool HasParentDistance = true;
-
   /**
    * The cover tree (or, this implementation of it) does not require that
    * children represent non-overlapping subsets of the parent node.
@@ -63,6 +48,11 @@ class TreeTraits<CoverTree<MetricType, RootPointPolicy, StatisticType> >
    * Cover trees do have self-children.
    */
   static const bool HasSelfChildren = true;
+
+  /**
+   * Points are not rearranged when the tree is built.
+   */
+  static const bool RearrangesDataset = false;
 };
 
 }; // namespace tree
