@@ -17,20 +17,12 @@
  * }
  * @endcode
  *
- * This file is part of MLPACK 1.0.8.
+ * This file is part of mlpack 1.0.12.
  *
- * MLPACK is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * MLPACK is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * MLPACK.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #ifndef __MLPACK_METHODS_EMST_DTB_HPP
 #define __MLPACK_METHODS_EMST_DTB_HPP
@@ -94,7 +86,7 @@ class DualTreeBoruvka
   //! Copy of the data (if necessary).
   typename TreeType::Mat dataCopy;
   //! Reference to the data (this is what should be used for accessing data).
-  typename TreeType::Mat& data;
+  const typename TreeType::Mat& data;
 
   //! Pointer to the root of the tree.
   TreeType* tree;
@@ -145,7 +137,6 @@ class DualTreeBoruvka
    */
   DualTreeBoruvka(const typename TreeType::Mat& dataset,
                   const bool naive = false,
-                  const size_t leafSize = 1,
                   const MetricType metric = MetricType());
 
   /**
@@ -165,7 +156,8 @@ class DualTreeBoruvka
    * @param tree Pre-built tree.
    * @param dataset Dataset corresponding to the pre-built tree.
    */
-  DualTreeBoruvka(TreeType* tree, const typename TreeType::Mat& dataset,
+  DualTreeBoruvka(TreeType* tree,
+                  const typename TreeType::Mat& dataset,
                   const MetricType metric = MetricType());
 
   /**
@@ -184,6 +176,11 @@ class DualTreeBoruvka
    */
   void ComputeMST(arma::mat& results);
 
+  /**
+   * Returns a string representation of this object.
+   */
+  std::string ToString() const;
+
  private:
   /**
    * Adds a single edge to the edge list
