@@ -4,26 +4,20 @@
  *
  * Tree traverser rules for the DualTreeBoruvka algorithm.
  *
- * This file is part of MLPACK 1.0.8.
+ * This file is part of mlpack 1.0.12.
  *
- * MLPACK is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * MLPACK is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * MLPACK.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #ifndef __MLPACK_METHODS_EMST_DTB_RULES_HPP
 #define __MLPACK_METHODS_EMST_DTB_RULES_HPP
 
 #include <mlpack/core.hpp>
 
+#include "../neighbor_search/ns_traversal_info.hpp"
+
 namespace mlpack {
 namespace emst {
 
@@ -87,7 +81,7 @@ class DTBRules
    * @param queryNode Candidate query node to recurse into.
    * @param referenceNode Candidate reference node to recurse into.
    */
-  double Score(TreeType& queryNode, TreeType& referenceNode) const;
+  double Score(TreeType& queryNode, TreeType& referenceNode);
 
   /**
    * Get the score for recursion order, passing the base case result (in the
@@ -101,7 +95,7 @@ class DTBRules
    */
   double Score(TreeType& queryNode,
                TreeType& referenceNode,
-               const double baseCaseResult) const;
+               const double baseCaseResult);
 
   /**
    * Re-evaluate the score for recursion order.  A low score indicates priority
@@ -118,6 +112,21 @@ class DTBRules
                  TreeType& referenceNode,
                  const double oldScore) const;
 
+  typedef neighbor::NeighborSearchTraversalInfo<TreeType> TraversalInfoType;
+
+  const TraversalInfoType& TraversalInfo() const { return traversalInfo; }
+  TraversalInfoType& TraversalInfo() { return traversalInfo; }
+
+  //! Get the number of base cases performed.
+  size_t BaseCases() const { return baseCases; }
+  //! Modify the number of base cases performed.
+  size_t& BaseCases() { return baseCases; }
+
+  //! Get the number of node combinations that have been scored.
+  size_t Scores() const { return scores; }
+  //! Modify the number of node combinations that have been scored.
+  size_t& Scores() { return scores; }
+
  private:
   //! The data points.
   const arma::mat& dataSet;
@@ -144,6 +153,13 @@ class DTBRules
    */
   inline double CalculateBound(TreeType& queryNode) const;
 
+  TraversalInfoType traversalInfo;
+
+  //! The number of base cases calculated.
+  size_t baseCases;
+  //! The number of node combinations that have been scored.
+  size_t scores;
+
 }; // class DTBRules
 
 } // emst namespace
