@@ -7,20 +7,12 @@
  * Calling unionfind.Union(x, y) unites the components indexed by x and y.
  * unionfind.Find(x) returns the index of the component containing point x.
  *
- * This file is part of MLPACK 1.0.8.
+ * This file is part of mlpack 1.0.12.
  *
- * MLPACK is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * MLPACK is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * MLPACK.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #ifndef __MLPACK_METHODS_EMST_UNION_FIND_HPP
 #define __MLPACK_METHODS_EMST_UNION_FIND_HPP
@@ -40,13 +32,12 @@ namespace emst {
 class UnionFind
 {
  private:
-  size_t size;
   arma::Col<size_t> parent;
   arma::ivec rank;
 
  public:
   //! Construct the object with the given size.
-  UnionFind(const size_t size) : size(size), parent(size), rank(size)
+  UnionFind(const size_t size) : parent(size), rank(size)
   {
     for (size_t i = 0; i < size; ++i)
     {
