@@ -4,20 +4,12 @@
  *
  * Implementation of FastMKSRules for cover tree search.
  *
- * This file is part of MLPACK 1.0.8.
+ * This file is part of mlpack 1.0.12.
  *
- * MLPACK is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * MLPACK is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * MLPACK.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #ifndef __MLPACK_METHODS_FASTMKS_FASTMKS_RULES_IMPL_HPP
 #define __MLPACK_METHODS_FASTMKS_FASTMKS_RULES_IMPL_HPP
@@ -55,6 +47,11 @@ FastMKSRules<KernelType, TreeType>::FastMKSRules(const arma::mat& referenceSet,
   for (size_t i = 0; i < referenceSet.n_cols; ++i)
     referenceKernels[i] = sqrt(kernel.Evaluate(referenceSet.unsafe_col(i),
                                                referenceSet.unsafe_col(i)));
+
+  // Set to invalid memory, so that the first node combination does not try to
+  // dereference null pointers.
+  traversalInfo.LastQueryNode() = (TreeType*) this;
+  traversalInfo.LastReferenceNode() = (TreeType*) this;
 }
 
 template<typename KernelType, typename TreeType>
@@ -212,18 +209,18 @@ double FastMKSRules<KernelType, TreeType>::Score(TreeType& queryNode,
   // First, see if we can make a parent-child or parent-parent prune.  These
   // four bounds on the maximum kernel value are looser than the bound normally
   // used, but they can prevent a base case from needing to be calculated.
-  const TreeType* queryParent = queryNode.Parent();
-  const TreeType* refParent = referenceNode.Parent();
 
   // Convenience caching so lines are shorter.
   const double queryParentDist = queryNode.ParentDistance();
   const double queryDescDist = queryNode.FurthestDescendantDistance();
   const double refParentDist = referenceNode.ParentDistance();
   const double refDescDist = referenceNode.FurthestDescendantDistance();
+  double adjustedScore = traversalInfo.LastBaseCase();
 
   const double queryDistBound = (queryParentDist + queryDescDist);
   const double refDistBound = (refParentDist + refDescDist);
-  const double dualTerm = queryDistBound * refDistBound;
+  double dualQueryTerm;
+  double dualRefTerm;
 
   // The parent-child and parent-parent prunes work by applying the same pruning
   // condition as when the parent node was used, except they are tighter because
@@ -233,64 +230,73 @@ double FastMKSRules<KernelType, TreeType>::Score(TreeType& queryNode,
   // so we construct the same bounds that were used when Score() was called with
   // the parents, except with the tighter distance bounds.  Sometimes this
   // allows us to prune nodes without evaluating the base cases between them.
-  if ((queryParent != NULL) &&
-      (queryParent->Stat().LastKernelNode() == (void*) &referenceNode))
+  if (traversalInfo.LastQueryNode() == queryNode.Parent())
   {
-    // Query parent was last evaluated with reference node.
-    const double queryKernelTerm =
-        refDistBound * queryParent->Stat().SelfKernel();
-    const double refKernelTerm =
-        queryDistBound * referenceNode.Stat().SelfKernel();
-    const double maxKernelBound = queryParent->Stat().LastKernel() +
-        queryKernelTerm + refKernelTerm + dualTerm;
-
-    if (maxKernelBound < bestKernel)
-      return DBL_MAX;
+    // We can assume that queryNode.Parent() != NULL, because at the root node
+    // combination, the traversalInfo.LastQueryNode() pointer will _not_ be
+    // NULL.  We also should be guaranteed that
+    // traversalInfo.LastReferenceNode() is either the reference node or the
+    // parent of the reference node.
+    adjustedScore += queryDistBound *
+        traversalInfo.LastReferenceNode()->Stat().SelfKernel();
+    dualQueryTerm = queryDistBound;
   }
-  else if ((refParent != NULL) &&
-      (refParent->Stat().LastKernelNode() == (void*) &queryNode))
+  else
   {
-    // Reference parent was last evaluated with query node.
-    const double queryKernelTerm = refDistBound * queryNode.Stat().SelfKernel();
-    const double refKernelTerm =
-        queryDistBound * refParent->Stat().SelfKernel();
-    const double maxKernelBound = refParent->Stat().LastKernel() +
-        queryKernelTerm + refKernelTerm + dualTerm;
-
-    if (maxKernelBound < bestKernel)
-      return DBL_MAX;
+    // The query parent could be NULL, which does weird things and we have to
+    // consider.
+    if (traversalInfo.LastReferenceNode() != NULL)
+    {
+      adjustedScore += queryDescDist *
+          traversalInfo.LastReferenceNode()->Stat().SelfKernel();
+      dualQueryTerm = queryDescDist;
+    }
+    else
+    {
+      // This makes it so a child-parent (or parent-parent) prune is not
+      // possible.
+      dualQueryTerm = 0.0;
+      adjustedScore = bestKernel;
+    }
   }
-  else if ((refParent != NULL) && (queryParent != NULL) &&
-      (queryParent->Stat().LastKernelNode() == (void*) refParent))
+
+  if (traversalInfo.LastReferenceNode() == referenceNode.Parent())
   {
-    // Query parent was last calculated with reference parent.
-    const double queryKernelTerm = (refParentDist + refDescDist) *
-        queryParent->Stat().SelfKernel();
-    const double refKernelTerm = (queryParentDist + queryDescDist) *
-        refParent->Stat().SelfKernel();
-    const double dualTerm = (queryParentDist + queryDescDist) * (refParentDist +
-        refDescDist);
-
-    const double maxKernelBound = queryParent->Stat().LastKernel() +
-        queryKernelTerm + refKernelTerm + dualTerm;
-
-    if (maxKernelBound < bestKernel)
-      return DBL_MAX;
+    // We can assume that referenceNode.Parent() != NULL, because at the root
+    // node combination, the traversalInfo.LastReferenceNode() pointer will
+    // _not_ be NULL.
+    adjustedScore += refDistBound *
+        traversalInfo.LastQueryNode()->Stat().SelfKernel();
+    dualRefTerm = refDistBound;
   }
-  else if ((refParent != NULL) && (queryParent != NULL) &&
-      (refParent->Stat().LastKernelNode() == (void*) queryParent))
+  else
   {
-    // Reference parent was last calculated with query parent.
-    const double queryKernelTerm = refDistBound *
-        queryParent->Stat().SelfKernel();
-    const double refKernelTerm = queryDistBound *
-        refParent->Stat().SelfKernel();
+    // The reference parent could be NULL, which does weird things and we have
+    // to consider.
+    if (traversalInfo.LastQueryNode() != NULL)
+    {
+      adjustedScore += refDescDist *
+          traversalInfo.LastQueryNode()->Stat().SelfKernel();
+      dualRefTerm = refDescDist;
+    }
+    else
+    {
+      // This makes it so a child-parent (or parent-parent) prune is not
+      // possible.
+      dualRefTerm = 0.0;
+      adjustedScore = bestKernel;
+    }
+  }
 
-    const double maxKernelBound = refParent->Stat().LastKernel() +
-        queryKernelTerm + refKernelTerm + dualTerm;
+  // Now add the dual term.
+  adjustedScore += (dualQueryTerm * dualRefTerm);
 
-    if (maxKernelBound < bestKernel)
-      return DBL_MAX;
+  if (adjustedScore < bestKernel)
+  {
+    // It is not possible that this node combination can contain a point
+    // combination with kernel value better than the minimum kernel value to
+    // improve any of the results, so we can prune it.
+    return DBL_MAX;
   }
 
   // We were unable to perform a parent-child or parent-parent prune, so now we
@@ -299,67 +305,29 @@ double FastMKSRules<KernelType, TreeType>::Score(TreeType& queryNode,
   if (tree::TreeTraits<TreeType>::FirstPointIsCentroid)
   {
     // For this type of tree, we may have already calculated the base case in
-    // the parents.  So see if it is already cached there.
-    bool alreadyDone = false;
-    if ((queryNode.Parent() != NULL) &&
-        (queryNode.Parent()->Point(0) == queryNode.Point(0)))
+    // the parents.
+    if ((traversalInfo.LastQueryNode() != NULL) &&
+        (traversalInfo.LastReferenceNode() != NULL) &&
+        (traversalInfo.LastQueryNode()->Point(0) == queryNode.Point(0)) &&
+        (traversalInfo.LastReferenceNode()->Point(0) == referenceNode.Point(0)))
     {
-      TreeType* lastRef = (TreeType*)
-          queryNode.Parent()->Stat().LastKernelNode();
-      if (lastRef->Point(0) == referenceNode.Point(0))
-      {
-        // The query node parent was evaluated with the reference node.
-        kernelEval = queryNode.Parent()->Stat().LastKernel();
-        alreadyDone = true;
-      }
-    }
+      // Base case already done.
+      kernelEval = traversalInfo.LastBaseCase();
 
-    if ((referenceNode.Parent() != NULL) &&
-        (referenceNode.Parent()->Point(0) == referenceNode.Point(0)))
-    {
-      TreeType* lastQuery = (TreeType*)
-          referenceNode.Parent()->Stat().LastKernelNode();
-      if (lastQuery->Point(0) == queryNode.Point(0))
-      {
-        // The reference node parent was evaluated with the query node.
-        kernelEval = referenceNode.Parent()->Stat().LastKernel();
-        alreadyDone = true;
-      }
+      // When BaseCase() is called after Score(), these must be correct so that
+      // another kernel evaluation is not performed.
+      lastQueryIndex = queryNode.Point(0);
+      lastReferenceIndex = referenceNode.Point(0);
     }
-
-    TreeType* lastRefNode = (TreeType*) referenceNode.Stat().LastKernelNode();
-    if ((lastRefNode != NULL) && (queryNode.Point(0) == lastRefNode->Point(0)))
-    {
-      // The kernel evaluation was already performed and is saved by the
-      // reference node.
-      kernelEval = referenceNode.Stat().LastKernel();
-      alreadyDone = true;
-    }
-
-    TreeType* lastQueryNode = (TreeType*) queryNode.Stat().LastKernelNode();
-    if ((lastQueryNode != NULL) &&
-        (referenceNode.Point(0) == lastQueryNode->Point(0)))
-    {
-      // The kernel evaluation was already performed and is saved by the query
-      // node.
-      kernelEval = queryNode.Stat().LastKernel();
-      alreadyDone = true;
-    }
-
-    if (!alreadyDone)
+    else
     {
       // The kernel must be evaluated, but it is between points in the dataset,
       // so we can call BaseCase().  BaseCase() will set lastQueryIndex and
       // lastReferenceIndex correctly.
       kernelEval = BaseCase(queryNode.Point(0), referenceNode.Point(0));
     }
-    else
-    {
-      // When BaseCase() is called after Score(), these must be correct so that
-      // another kernel evaluation is not performed.
-      lastQueryIndex = queryNode.Point(0);
-      lastReferenceIndex = referenceNode.Point(0);
-    }
+
+    traversalInfo.LastBaseCase() = kernelEval;
   }
   else
   {
@@ -370,6 +338,8 @@ double FastMKSRules<KernelType, TreeType>::Score(TreeType& queryNode,
     referenceNode.Centroid(refCentroid);
 
     kernelEval = kernel.Evaluate(queryCentroid, refCentroid);
+
+    traversalInfo.LastBaseCase() = kernelEval;
   }
   ++scores;
 
@@ -409,10 +379,8 @@ double FastMKSRules<KernelType, TreeType>::Score(TreeType& queryNode,
   }
 
   // Store relevant information for parent-child pruning.
-  queryNode.Stat().LastKernel() = kernelEval;
-  queryNode.Stat().LastKernelNode() = (void*) &referenceNode;
-  referenceNode.Stat().LastKernel() = kernelEval;
-  referenceNode.Stat().LastKernelNode() = (void*) &queryNode;
+  traversalInfo.LastQueryNode() = &queryNode;
+  traversalInfo.LastReferenceNode() = &referenceNode;
 
   // We return the inverse of the maximum kernel so that larger kernels are
   // recursed into first.
