@@ -1,30 +1,23 @@
 /**
  * @file kernel_pca.hpp
  * @author Ajinkya Kale
+ * @author Marcus Edel
  *
  * Defines the KernelPCA class to perform Kernel Principal Components Analysis
  * on the specified data set.
  *
- * This file is part of MLPACK 1.0.8.
+ * This file is part of mlpack 1.0.12.
  *
- * MLPACK is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * MLPACK is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * MLPACK.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #ifndef __MLPACK_METHODS_KERNEL_PCA_KERNEL_PCA_HPP
 #define __MLPACK_METHODS_KERNEL_PCA_KERNEL_PCA_HPP
 
 #include <mlpack/core.hpp>
-#include <mlpack/core/kernels/linear_kernel.hpp>
+#include <mlpack/methods/kernel_pca/kernel_rules/naive_method.hpp>
 
 namespace mlpack {
 namespace kpca {
@@ -42,7 +35,10 @@ namespace kpca {
  * files in mlpack/core/kernels/) and it is easy to write your own; see other
  * implementations for examples.
  */
-template <typename KernelType>
+template <
+  typename KernelType,
+  typename KernelRule = NaiveKernelRule<KernelType>
+>
 class KernelPCA
 {
  public:
@@ -53,10 +49,26 @@ class KernelPCA
    * much).
    *
    * @param kernel Kernel to be used for computation.
+   * @param centerTransformedData Center transformed data.
    */
   KernelPCA(const KernelType kernel = KernelType(),
             const bool centerTransformedData = false);
 
+  /**
+   * Apply Kernel Principal Components Analysis to the provided data set.
+   *
+   * @param data Data matrix.
+   * @param transformedData Matrix to output results into.
+   * @param eigval KPCA eigenvalues will be written to this vector.
+   * @param eigvec KPCA eigenvectors will be written to this matrix.
+   * @param newDimension New dimension for the dataset.
+   */
+  void Apply(const arma::mat& data,
+             arma::mat& transformedData,
+             arma::vec& eigval,
+             arma::mat& eigvec,
+             const size_t newDimension);
+
   /**
    * Apply Kernel Principal Components Analysis to the provided data set.
    *
@@ -105,6 +117,9 @@ class KernelPCA
   bool CenterTransformedData() const { return centerTransformedData; }
   //! Return whether or not the transformed data is centered.
   bool& CenterTransformedData() { return centerTransformedData; }
+   
+  // Returns a string representation of this object. 
+  std::string ToString() const;
 
  private:
   //! The instantiated kernel.
@@ -113,14 +128,6 @@ class KernelPCA
   //! run.
   bool centerTransformedData;
 
-  /**
-   * Construct the kernel matrix.
-   *
-   * @param data Input data points.
-   * @param kernelMatrix Matrix to store the constructed kernel matrix in.
-   */
-  void GetKernelMatrix(const arma::mat& data, arma::mat& kernelMatrix);
-
 }; // class KernelPCA
 
 }; // namespace kpca
