@@ -16,25 +16,16 @@
  * Although this option currently is not implemented, it will be implemented
  * very soon.
  *
- * This file is part of MLPACK 1.0.8.
+ * This file is part of mlpack 1.0.12.
  *
- * MLPACK is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * MLPACK is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * MLPACK.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #ifndef __MLPACK_METHODS_LARS_LARS_HPP
 #define __MLPACK_METHODS_LARS_LARS_HPP
 
-#include <armadillo>
 #include <mlpack/core.hpp>
 
 namespace mlpack {
@@ -165,8 +156,11 @@ class LARS
 
   //! Access the upper triangular cholesky factor
   const arma::mat& MatUtriCholFactor() const { return matUtriCholFactor; }
-  
-private:
+
+  // Returns a string representation of this object.
+  std::string ToString() const;
+
+ private:
   //! Gram matrix.
   arma::mat matGramInternal;
 
@@ -204,6 +198,14 @@ private:
   //! Active set membership indicator (for each dimension).
   std::vector<bool> isActive;
 
+  // Set of variables that are ignored (if any).
+
+  //! Set of ignored variables (for dimensions in span{active set dimensions}).
+  std::vector<size_t> ignoreSet;
+
+  //! Membership indicator for set of ignored variables.
+  std::vector<bool> isIgnored;
+
   /**
    * Remove activeVarInd'th element from active set.
    *
@@ -218,6 +220,13 @@ private:
    */
   void Activate(const size_t varInd);
 
+  /**
+   * Add dimension varInd to ignores set (never removed).
+   *
+   * @param varInd Dimension to add to ignores set.
+   */
+  void Ignore(const size_t varInd);
+
   // compute "equiangular" direction in output space
   void ComputeYHatDirection(const arma::mat& matX,
                             const arma::vec& betaDirection,
