@@ -5,20 +5,12 @@
  * Defines the NeighborSearch class, which performs an abstract
  * nearest-neighbor-like query on two datasets.
  *
- * This file is part of MLPACK 1.0.8.
+ * This file is part of mlpack 1.0.12.
  *
- * MLPACK is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * MLPACK is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * MLPACK.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #ifndef __MLPACK_METHODS_NEIGHBOR_SEARCH_NEIGHBOR_SEARCH_HPP
 #define __MLPACK_METHODS_NEIGHBOR_SEARCH_NEIGHBOR_SEARCH_HPP
@@ -87,7 +79,6 @@ class NeighborSearch
                  const typename TreeType::Mat& querySet,
                  const bool naive = false,
                  const bool singleMode = false,
-                 const size_t leafSize = 20,
                  const MetricType metric = MetricType());
 
   /**
@@ -114,7 +105,6 @@ class NeighborSearch
   NeighborSearch(const typename TreeType::Mat& referenceSet,
                  const bool naive = false,
                  const bool singleMode = false,
-                 const size_t leafSize = 20,
                  const MetricType metric = MetricType());
 
   /**
@@ -208,17 +198,20 @@ class NeighborSearch
               arma::Mat<size_t>& resultingNeighbors,
               arma::mat& distances);
 
+  // Returns a string representation of this object. 
+  std::string ToString() const;
+
  private:
   //! Copy of reference dataset (if we need it, because tree building modifies
   //! it).
-  arma::mat referenceCopy;
+  typename TreeType::Mat referenceCopy;
   //! Copy of query dataset (if we need it, because tree building modifies it).
-  arma::mat queryCopy;
+  typename TreeType::Mat queryCopy;
 
   //! Reference dataset.
-  const arma::mat& referenceSet;
+  const typename TreeType::Mat& referenceSet;
   //! Query dataset (may not be given).
-  const arma::mat& querySet;
+  const typename TreeType::Mat& querySet;
 
   //! Pointer to the root of the reference tree.
   TreeType* referenceTree;
@@ -242,9 +235,6 @@ class NeighborSearch
   std::vector<size_t> oldFromNewReferences;
   //! Permutations of query points during tree building.
   std::vector<size_t> oldFromNewQueries;
-
-  //! Total number of pruned nodes during the neighbor search.
-  size_t numberOfPrunes;
 }; // class NeighborSearch
 
 }; // namespace neighbor
