@@ -4,26 +4,19 @@
  *
  * Implementation of the simple NearestNeighborSort policy class.
  *
- * This file is part of MLPACK 1.0.8.
+ * This file is part of mlpack 1.0.12.
  *
- * MLPACK is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * MLPACK is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * MLPACK.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include "nearest_neighbor_sort.hpp"
 
 using namespace mlpack::neighbor;
 
 size_t NearestNeighborSort::SortDistance(const arma::vec& list,
+                                         const arma::Col<size_t>& indices,
                                          double newDistance)
 {
   // The first element in the list is the nearest neighbor.  We only want to
@@ -33,8 +26,8 @@ size_t NearestNeighborSort::SortDistance(const arma::vec& list,
 
   // Search from the beginning.  This may not be the best way.
   for (size_t i = 0; i < list.n_elem; i++)
-    if (newDistance <= list[i])
-      return i;  
+    if (newDistance <= list[i] || indices[i] == (size_t() - 1))
+      return i;
 
   // Control should never reach here.
   return (size_t() - 1);
