@@ -5,20 +5,12 @@
  * Implementation of the SortPolicy class for NeighborSearch; in this case, the
  * nearest neighbors are those that are most important.
  *
- * This file is part of MLPACK 1.0.8.
+ * This file is part of mlpack 1.0.12.
  *
- * MLPACK is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * MLPACK is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * MLPACK.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #ifndef __MLPACK_METHODS_NEIGHBOR_SEARCH_NEAREST_NEIGHBOR_SORT_HPP
 #define __MLPACK_METHODS_NEIGHBOR_SEARCH_NEAREST_NEIGHBOR_SORT_HPP
@@ -55,7 +47,9 @@ class NearestNeighborSort
    * @return size_t containing the position to insert into, or (size_t() - 1)
    *     if the new distance should not be inserted.
    */
-  static size_t SortDistance(const arma::vec& list, double newDistance);
+  static size_t SortDistance(const arma::vec& list,
+                             const arma::Col<size_t>& indices,
+                             double newDistance);
 
   /**
    * Return whether or not value is "better" than ref.  In this case, that means
@@ -113,8 +107,8 @@ class NearestNeighborSort
    * this is the minimum distance between the tree node and the point using the
    * given distance function.
    */
-  template<typename TreeType>
-  static double BestPointToNodeDistance(const arma::vec& queryPoint,
+  template<typename VecType, typename TreeType>
+  static double BestPointToNodeDistance(const VecType& queryPoint,
                                         const TreeType* referenceNode);
 
   /**
@@ -123,8 +117,8 @@ class NearestNeighborSort
    * calculated.  This is used in conjunction with trees that have
    * self-children (like cover trees).
    */
-  template<typename TreeType>
-  static double BestPointToNodeDistance(const arma::vec& queryPoint,
+  template<typename VecType, typename TreeType>
+  static double BestPointToNodeDistance(const VecType& queryPoint,
                                         const TreeType* referenceNode,
                                         const double pointToCenterDistance);
 
