@@ -5,30 +5,19 @@
  * Defines the RangeSearch class, which performs a generalized range search on
  * points.
  *
- * This file is part of MLPACK 1.0.8.
+ * This file is part of mlpack 1.0.12.
  *
- * MLPACK is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * MLPACK is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * MLPACK.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #ifndef __MLPACK_METHODS_RANGE_SEARCH_RANGE_SEARCH_HPP
 #define __MLPACK_METHODS_RANGE_SEARCH_RANGE_SEARCH_HPP
 
 #include <mlpack/core.hpp>
-
 #include <mlpack/core/metrics/lmetric.hpp>
-
 #include <mlpack/core/tree/binary_space_tree.hpp>
-
 #include "range_search_stat.hpp"
 
 namespace mlpack {
@@ -69,7 +58,6 @@ class RangeSearch
               const typename TreeType::Mat& querySet,
               const bool naive = false,
               const bool singleMode = false,
-              const size_t leafSize = 20,
               const MetricType metric = MetricType());
 
   /**
@@ -94,7 +82,6 @@ class RangeSearch
   RangeSearch(const typename TreeType::Mat& referenceSet,
               const bool naive = false,
               const bool singleMode = false,
-              const size_t leafSize = 20,
               const MetricType metric = MetricType());
 
   /**
@@ -201,6 +188,9 @@ class RangeSearch
               std::vector<std::vector<size_t> >& neighbors,
               std::vector<std::vector<double> >& distances);
 
+  // Returns a string representation of this object. 
+  std::string ToString() const;
+
  private:
   //! Copy of reference matrix; used when a tree is built internally.
   typename TreeType::Mat referenceCopy;
