@@ -4,20 +4,12 @@
  *
  * Test for the Gaussian Mixture Model class.
  *
- * This file is part of MLPACK 1.0.10.
+ * This file is part of mlpack 1.0.12.
  *
- * MLPACK is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * MLPACK is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * MLPACK.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include <mlpack/core.hpp>
 
@@ -342,8 +334,6 @@ BOOST_AUTO_TEST_CASE(GMMTrainEMMultipleGaussians)
  */
 BOOST_AUTO_TEST_CASE(GMMTrainEMSingleGaussianWithProbability)
 {
-  math::RandomSeed(std::time(NULL));
-
   // Generate observations from a Gaussian distribution.
   distribution::GaussianDistribution d("0.5 1.0", "1.0 0.3; 0.3 1.0");
 
@@ -378,8 +368,6 @@ BOOST_AUTO_TEST_CASE(GMMTrainEMSingleGaussianWithProbability)
  */
 BOOST_AUTO_TEST_CASE(GMMTrainEMMultipleGaussiansWithProbability)
 {
-  srand(time(NULL));
-
   // We'll have three Gaussian distributions from this mixture, and one Gaussian
   // not from this mixture (but we'll put some observations from it in).
   distribution::GaussianDistribution d1("0.0 1.0 0.0", "1.0 0.0 0.5;"
@@ -397,10 +385,10 @@ BOOST_AUTO_TEST_CASE(GMMTrainEMMultipleGaussiansWithProbability)
 
   // Now we'll generate points and probabilities.  1500 points.  Slower than I
   // would like...
-  arma::mat points(3, 2000);
-  arma::vec probabilities(2000);
+  arma::mat points(3, 5000);
+  arma::vec probabilities(5000);
 
-  for (size_t i = 0; i < 2000; i++)
+  for (size_t i = 0; i < 5000; i++)
   {
     double randValue = math::Random();
 
@@ -417,8 +405,8 @@ BOOST_AUTO_TEST_CASE(GMMTrainEMMultipleGaussiansWithProbability)
     // 0.97 plus or minus a little bit of noise.  If not, then it should be 0.03
     // plus or minus a little bit of noise.  The base probability (minus the
     // noise) is parameterizable for easy modification of the test.
-    double confidence = 0.995;
-    double perturbation = math::Random(-0.005, 0.005);
+    double confidence = 0.998;
+    double perturbation = math::Random(-0.002, 0.002);
 
     if (randValue <= 0.90)
       probabilities(i) = confidence + perturbation;
@@ -446,8 +434,8 @@ BOOST_AUTO_TEST_CASE(GMMTrainEMMultipleGaussiansWithProbability)
 
   for (size_t row = 0; row < 3; row++)
     for (size_t col = 0; col < 3; col++)
-      BOOST_REQUIRE_SMALL((g.Covariances()[sortedIndices[0]](row, col) -
-          d4.Covariance()(row, col)), 0.60); // Big tolerance!  Lots of noise.
+      BOOST_REQUIRE_SMALL((g.Covariances()[sortedIndices[0]](row, col)
+          - d4.Covariance()(row, col)), 0.7); // Big tolerance!  Lots of noise.
 
   // Second Gaussian (d1).
   BOOST_REQUIRE_SMALL(g.Weights()[sortedIndices[1]] - 0.2, 0.1);
@@ -457,8 +445,8 @@ BOOST_AUTO_TEST_CASE(GMMTrainEMMultipleGaussiansWithProbability)
 
   for (size_t row = 0; row < 3; row++)
     for (size_t col = 0; col < 3; col++)
-      BOOST_REQUIRE_SMALL((g.Covariances()[sortedIndices[1]](row, col) -
-          d1.Covariance()(row, col)), 0.55); // Big tolerance!  Lots of noise.
+      BOOST_REQUIRE_SMALL((g.Covariances()[sortedIndices[1]](row, col)
+          - d1.Covariance()(row, col)), 0.7); // Big tolerance!  Lots of noise.
 
   // Third Gaussian (d2).
   BOOST_REQUIRE_SMALL(g.Weights()[sortedIndices[2]] - 0.3, 0.1);
@@ -468,8 +456,8 @@ BOOST_AUTO_TEST_CASE(GMMTrainEMMultipleGaussiansWithProbability)
 
   for (size_t row = 0; row < 3; row++)
     for (size_t col = 0; col < 3; col++)
-      BOOST_REQUIRE_SMALL((g.Covariances()[sortedIndices[2]](row, col) -
-          d2.Covariance()(row, col)), 0.50); // Big tolerance!  Lots of noise.
+      BOOST_REQUIRE_SMALL((g.Covariances()[sortedIndices[2]](row, col)
+          - d2.Covariance()(row, col)), 0.7); // Big tolerance!  Lots of noise.
 
   // Fourth gaussian (d3).
   BOOST_REQUIRE_SMALL(g.Weights()[sortedIndices[3]] - 0.4, 0.1);
@@ -479,8 +467,8 @@ BOOST_AUTO_TEST_CASE(GMMTrainEMMultipleGaussiansWithProbability)
 
   for (size_t row = 0; row < 3; ++row)
     for (size_t col = 0; col < 3; ++col)
-      BOOST_REQUIRE_SMALL((g.Covariances()[sortedIndices[3]](row, col) -
-          d3.Covariance()(row, col)), 0.50);
+      BOOST_REQUIRE_SMALL((g.Covariances()[sortedIndices[3]](row, col)
+          - d3.Covariance()(row, col)), 0.7);
 }
 
 /**
