@@ -4,20 +4,12 @@
  *
  * Tests for data::Load() and data::Save().
  *
- * This file is part of MLPACK 1.0.10.
+ * This file is part of mlpack 1.0.12.
  *
- * MLPACK is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * MLPACK is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * MLPACK.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redstribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include <sstream>
 
@@ -393,7 +385,9 @@ BOOST_AUTO_TEST_CASE(SavePGMBinaryTest)
   remove("test_file.pgm");
 }
 
-#ifdef ARMA_USE_HDF5
+#if defined(ARMA_USE_HDF5) && (ARMA_VERSION_MAJOR == 3 \
+    || (ARMA_VERSION_MAJOR == 4 && (ARMA_VERSION_MINOR < 300 \
+    ||  ARMA_VERSION_MINOR > 400)))
 /**
  * Make sure load as HDF5 is successful.
  */
